Rigo Ride On Car Tractor Toy Kids Electric Cars 12V Battery Child Toddlers Blue - Shopnado
Description: Looking for a perfect birthday or Christmas gift to surprise your little ones? The Rigo brings kids’ ride-on farm Tractor with a trailer to give your kids utmost pleasure. Our ride-on tractor with a detachable trailer has cool features, such as powerful twin motors, 7-LED headlights, and Bluetooth function for a real-like play. The functional […]

### Search

Search
0

# Rigo Ride On Car Tractor Toy Kids Electric Cars 12V Battery Child Toddlers Blue

Availability: In stock

$286.00
Rigo Ride On Car Tractor Toy Kids Electric Cars 12V Battery Child Toddlers Blue quantity
Compare
Add to wishlist
Add to wishlist
Compare

- Description
- Additional information

Looking for a perfect birthday or Christmas gift to surprise your little ones? The Rigo brings kids’ ride-on farm Tractor with a trailer to give your kids utmost pleasure. Our ride-on tractor with a detachable trailer has cool features, such as powerful twin motors, 7-LED headlights, and Bluetooth function for a real-like play. The functional dashboard allows you to control speed, forward/reverse, and turn on/off the music. Furthermore, the keyless button start makes for a hassle-free play experience. Your child’s safety is also assured with anti-slip tyres and a secured seat. This toy is perfect to give your children fun and imaginative playtime.

Please Note:
1. Charge the battery on receiving even if it will not be used soon.
2. Charge the battery EVERY MONTH if not in use for long periods to prevent over-discharging of the battery. This can cause irreparable damage to it.

Features
Twin motors
7 LED headlights
Detachable large trailer
Functional dashboard
Seat with a safety belt and armrests
High/low speed control
Rechargeable battery
USB input
Bluetooth function
Anti-slip tyres
EN71 certified
Recommended for children aged 3 years and above

Specifications:
Control mode: Manual
Motor: 50W(2 x 25W)
Battery:12V4.5AH
Speed: 3-6km/h
Speed mode: High/low
Operating time: Up to 2 hours per full charge
Load capacity: 30kg
Built-in music: Yes
Headlight: Yes
Power indicator: Yes
Seat belt: adjustable
Recommended user age: 3+ years old
Colour: Blue

Package Content
1 x Rigo Ride On Tractor
1 x User Manual
1 x Batter Charger

Weight | 10.6 kg
Dimensions | 84 × 50 × 40 cm

### Related Products

Save 31%
$290.00 Original price was: $290.00.$200.00Current price is: $200.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare

### BMW i7

5.00 out of 5
1 review(s)

### BMW i7

5.00 out of 5
1 review(s)
This BMWI7 inspired car will bring countless hours of smile and joy to your little ones. Sleek design and sturdy built with four wheel suspension for added stability and comfort....
$290.00 Original price was: $290.00.$200.00Current price is: $200.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare
Hot
Save 24%
$460.00 Original price was: $460.00.$350.00Current price is: $350.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare

### Jeep Wrangler 4X4

0 out of 5
0 review(s)

### Jeep Wrangler 4X4

0 out of 5
0 review(s)
This Jeep Wrangler inspired SUV will bring countless hours of smile and joy to your little ones. Sleek design and sturdy built with four wheel suspension for added stability and...
$460.00 Original price was: $460.00.$350.00Current price is: $350.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare
Save 35%
$800.00 Original price was: $800.00.$520.00Current price is: $520.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare

### Rolls Royce Cullinan

0 out of 5
0 review(s)

### Rolls Royce Cullinan

0 out of 5
0 review(s)
This Rolls Royce Cullinan inspired car will bring countless hours of smile and joy to your little ones. Sleek design and sturdy built with four wheel suspension for added stability...
$800.00 Original price was: $800.00.$520.00Current price is: $520.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare
$315.00

Add to cart

Quick View
Add to wishlist
Compare

### Rigo Kids Ride On Bulldozer Digger Electric Car Yellow

0 out of 5
0 review(s)

### Rigo Kids Ride On Bulldozer Digger Electric Car Yellow

0 out of 5
0 review(s)
Next Level Excitement Not just an ordinary ride, but a fun and industrial tractor! Give your kids an experience that are different and full of excitement. Simple and straightforward operation,...
$315.00

Add to cart

Quick View
Add to wishlist
Compare
Save 40%
$540.00 Original price was: $540.00.$325.00Current price is: $325.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare

### Ferrari 812

5.00 out of 5
1 review(s)

### Ferrari 812

5.00 out of 5
1 review(s)
This Ferrari 812 inspired car will bring countless hours of smile and joy to your little ones. Sleek design and sturdy built with four wheel suspension for added stability and...
$540.00 Original price was: $540.00.$325.00Current price is: $325.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare
$286.00

Add to cart

Quick View
Add to wishlist
Compare

### Rigo Ride On Car Tractor Toy Kids Electric Cars 12V Battery Child Toddlers Red

0 out of 5
0 review(s)

### Rigo Ride On Car Tractor Toy Kids Electric Cars 12V Battery Child Toddlers Red

0 out of 5
0 review(s)
Looking for a perfect birthday or Christmas gift to surprise your little ones? The Rigo brings kids’ ride-on farm Tractor with a trailer to give your kids utmost pleasure. Our...
$286.00

Add to cart

Quick View
Add to wishlist
Compare
Save 36%
$350.00 Original price was: $350.00.$225.00Current price is: $225.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare

### Bentley Continental GT

0 out of 5
0 review(s)

### Bentley Continental GT

0 out of 5
0 review(s)
This Bentley Continental GT inspired car will bring countless hours of smile and joy to your little ones. Sleek design and sturdy built with four wheel suspension for added stability...
$350.00 Original price was: $350.00.$225.00Current price is: $225.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare
Save 40%
$990.00 Original price was: $990.00.$595.00Current price is: $595.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare

### Beach Buggy

5.00 out of 5
1 review(s)

### Beach Buggy

5.00 out of 5
1 review(s)
This 4WDbeach buggy will bring countless hours of smile and joy to your little ones. Sleek design and sturdy built with four wheel suspension for added stability and comfort. Other...
$990.00 Original price was: $990.00.$595.00Current price is: $595.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare
Save 32%
$410.00 Original price was: $410.00.$280.00Current price is: $280.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare

### Lexus RX

0 out of 5
0 review(s)

### Lexus RX

0 out of 5
0 review(s)
This Lexus RX inspired car will bring countless hours of smile and joy to your little ones. Sleek design and sturdy built with four wheel suspension for added stability and...
$410.00 Original price was: $410.00.$280.00Current price is: $280.00.

Select options This product has multiple variants. The options may be chosen on the product page

Quick View
Add to wishlist
Compare

### shopnado up your inbox!

Your kids will thank you !

Email *

Copyright © 2021-2023 shopnado.com.au. All Rights Reserved.
0